<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>AutoZoom</name>
    <message>
        <location filename="../AutoZoomInit.js" line="+2"/>
        <source>&amp;Auto Zoom</source>
        <translation>&amp;Automatické přiblížení</translation>
    </message>
</context>
</TS>
